%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% acm.cls
%% LaTeX2e class file to format manuscript for the journal Applied and Computational Mechanics
%  requires following LaTeX packages:
%  graphicx.sty
%  amssymb.sty
%  amsmath.sty
%  bm.sty
%  fancyhdr.sty
%  geometry.sty
%
% Authors: Vladimir Lukes, Vitezslav Adamek, University of West Bohemia in Pilsen
% maketitle code inspired by iccbb.cls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{acm}

\DeclareOption*{%
   \PassOptionsToClass{\CurrentOption}{article}%
}
\ProcessOptions\relax

\LoadClass[a4paper,12pt]{article}

\RequirePackage{amssymb}
\RequirePackage{amsmath}
\RequirePackage{graphicx}
\RequirePackage{fancyhdr}
\RequirePackage{times}
\RequirePackage{bm}
\RequirePackage{caption}
\RequirePackage[a4paper, 
                left=25mm, width =160mm,
                top =25mm, height=240mm]{geometry}
\RequirePackage{array}                


% VERTICAL SPACING        
\topmargin      -10mm             
\headheight     13mm             
\headsep        10pt             
\footskip       30pt             


\def \@discardtok #1{}%                                  token
\def \@name #1{%                                        {\tokens}
  \csname \expandafter\@discardtok \string#1\endcsname}
\def \@withname #1#2{%                                  {\command}{\tokens}
  \expandafter#1\csname \expandafter\@discardtok \string#2\endcsname}
\def \@increment #1{\advance #1 by 1\relax}%             {\count}


% TITLE PAGE
\def \@titletext {\@latex@error{No title was provided}{}}

\newcount{\@authorcount}
\newcount{\@authorindex}

\newcount{\@affilcount}
\newcount{\@affilindex}

\renewcommand{\title}[1]{%
  \gdef \@titletext {#1}
}

\newcommand{\authorinfo}[2] {
  \global\@increment \@authorcount
  \@withname\gdef {\@authorname\the\@authorcount}{#1}
  \@withname\gdef {\@authoraffil\the\@authorcount}{#2}
}

\newcommand{\affiliation}[2] {
  \global\@increment \@affilcount
  \@withname\gdef {\@affilident\the\@affilcount}{{\fontsize{8pt}{9.6pt}\selectfont #1}}
  \@withname\gdef {\@affiltext\the\@affilcount}{{\fontsize{8pt}{9.6pt}\selectfont\textit{#2}}}
}

\renewcommand{\author}[1]{%
  \@latex@error{The \string\author\space command is obsolete;
                use \string\authorinfo}{}
}

\newcommand{\setdates}[2] {
  \gdef\datefrom{#1}
  \gdef\dateto{#2}
}

\def \@maketitle {%
  \begin{center}
  \vspace*{10mm}
  \noindent \Large\@titletext\par
  \vspace*{6pt}
  \noindent
  \ifcase \@authorcount
     \@latex@error{No authors were specified for this paper}{}\or
  \fi
  \global\@authorindex=0
  \@authorloop
  \par 
  \vspace*{6pt}
  \noindent
  \ifcase \@affilcount
     \@latex@error{No affiliations were specified for this paper}{}\or
  \fi
  \global\@affilindex=0
  \@affilloop
  \vspace*{6pt}
  {\fontsize{8pt}{9.6pt}\selectfont \ %Received \datefrom ; received in revised form \dateto
   } 
  \end{center}
}

\def \@authorloop {%
  \relax\ifnum\@authorindex<\@authorcount\@increment{\@authorindex}
    \@setauthor{\the\@authorindex}
    \ifnum\@authorindex<\@authorcount\unskip \large,\fi
    \@authorloop
  \fi
}

\def \@affilloop {
  \relax\ifnum\@affilindex<\@affilcount\@increment{\@affilindex}
     \@setaffil{\the\@affilindex}
     \@affilloop
  \fi
}

\def \@setauthor#1 {
  \large\mbox{\@name{\@authorname#1}$^{\@name{\@authoraffil#1}}$}
}

\def \@setaffil#1 {
  \normalsize$^{\@name{\@affilident#1}}$\@name{\@affiltext#1}\par
  \vspace{-4pt}
}


%ABSTRACT AND KEYWORDS FORMAT
\renewcommand {\abstract}[2]{%
  \noindent\hrulefill\par
  \vskip6pt
  \noindent
  \fontsize{10pt}{12pt}\selectfont
  \textbf{Abstract}\par
  \vskip6pt\noindent#1\par
  \noindent
  \ %\copyright \,Copyright statement. 
  \par
  \vskip6pt
  \noindent
  \textit{Keywords:} #2\par
  \vskip2pt
  \noindent\hrulefill\par
  \vskip6pt
  \fontsize{12pt}{14.5pt}\selectfont
  \thispagestyle{empty}
}


%CORRESPONDING AUTHOR FOOTNOTE
\renewcommand{\thefootnote}{\fnsymbol{footnote}}
\newcommand{\mainauthor}[2]{%
  \addtocounter{footnote}{1}
  \footnotetext{Corresponding author. Tel.: #1, e-mail: #2.}
  \addtocounter{footnote}{-1}
  \renewcommand{\thefootnote}{\arabic{footnote}}
}


%FIGURE AND TABLE CAPTIONS FORMAT
\renewcommand{\figurename}{Fig.}
\renewcommand{\tablename}{Table}
\def\fnum@figure{\small \figurename~\thefigure.}
\def\fnum@table{\small \tablename~\thetable.}

\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{#1 #2}%
  \ifdim \wd\@tempboxa >\hsize
    #1 #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip
}


%SECTION, SUBSECTION AND SUBSUBSECTION FORMAT
\renewcommand{\thesection}{\@arabic\c@section}
\renewcommand{\thesubsection}{\@arabic\c@section.\@arabic\c@subsection}
\renewcommand{\thesubsubsection}
{\@arabic\c@section.\@arabic\c@subsection.\@arabic\c@subsubsection}

\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {-18pt \@plus -1ex \@minus -.2ex}%
                                   {8pt \@plus.2ex}%
                                   {\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-12pt\@plus -1ex \@minus -.2ex}%
                                     {6pt \@plus .2ex}%
                                     {\itshape}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-12pt\@plus -1ex \@minus -.2ex}%
                                     {6pt \@plus .2ex}%
                                     {\itshape}}


%HEADING FORMAT
\renewcommand{\headrulewidth}{0pt}
\newcommand{\setacm}[2]{
  \gdef\acmvolume{#1}
  \gdef\acmyear{#2}
}

\newcommand{\setpages}[2]{
  \gdef\pagefrom{#1}
  \gdef\pageto{#2}
}
	
\newcommand{\acmheadtitle}{\small Applied and Computational Mechanics \acmvolume\ (\acmyear) \pagefrom--\pageto}

\AtBeginDocument{
%  \let\@afterindentfalse\@afterindenttrue
%  \@afterindenttrue
  \pagestyle{fancy}
  \fancyhead{}
  \ifnum\@authorcount>1 \fancyhead[C]{\small \ } %\textit{\@name{\@authorname1} et al. / \acmheadtitle}}
  \else \fancyhead[C]{\small \textit{\@name{\@authorname1} / \acmheadtitle}} \fi
  \fancyfoot{}
}


%BIBLIOGRAPHY
\newdimen\bibindent
\setlength\bibindent{1.5em}
\renewenvironment{thebibliography}[1]
  {\section*{\refname}%
    \@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}%
    \list{\@biblabel{\@arabic\c@enumiv}}%
    {\setlength{\itemsep}{-4pt} 
      \small{\settowidth\labelwidth{\@biblabel{#1}}}%
      \leftmargin\labelwidth
      \advance\leftmargin\labelsep
      \@openbib@code
      \usecounter{enumiv}%
      \let\p@enumiv\@empty
      \renewcommand\theenumiv{\@arabic\c@enumiv}}%
    \sloppy
    \clubpenalty4000
    \@clubpenalty \clubpenalty
    \widowpenalty4000%
    \sfcode`\.\@m}
  {\def\@noitemerr
    {\@latex@warning{Empty `thebibliography' environment}}%
    \endlist}

      
% aux. macros
\newcommand{\cmd}[1]{{\small \texttt{$\backslash$#1}}}
\newcommand{\ar}[1]{{\small \texttt{#1}}}
